@@ -260,26 +260,67 @@ class Listing(Container):
   def __init__(self):
     self.parser = InsetParser()
     self.output = TaggedOutput().settag('code class="listing"', True)
+    self.numbered = None
+    self.counter = 0
 
   def process(self):
     "Remove all layouts"
+    self.processparams()
     newcontents = []
     for container in self.contents:
       newcontents += self.extract(container)
     self.contents = newcontents
 
+  def processparams(self):
+    "Process listing parameteres"
+    paramlist = self.parameters['lstparams'].split(',')
+    for param in paramlist:
+      if not '=' in param:
+        Trace.error('Invalid listing parameter ' + param)
+      else:
+        key, value = param.split('=', 1)
+        self.parameters[key] = value
+        if key == 'numbers':
+          self.numbered = value
+
   def extract(self, container):
     "Extract the container's contents and return them"
     if isinstance(container, StringContainer):
       return [container]
     if isinstance(container, Layout):
-      if len(container.contents) == 0:
-        return []
-      last = container.contents[-1]
-      if isinstance(last, StringContainer):
-        last.contents.append('\n')
-      return container.contents
+      return self.modifylayout(container.contents)
     Trace.error('Unexpected container ' + container.__class__.__name__ +
         ' in listing')
     return []
 
+  def modifylayout(self, contents):
+    "Modify a listing layout contents"
+    if len(contents) == 0:
+      contents = [Constant(u'​')]
+    contents.append(Constant('\n'))
+    if self.numbered:
+      self.counter += 1
+      tag = 'span class="number-' + self.numbered + '"'
+      contents.insert(0, TaggedText().constant(str(self.counter), tag))
+    return contents
+
+class BoxInset(Container):
+  "A box inset"
+
+  ending = '\\end_inset'
+
+  typetags = {'Framed':'div class="framed"'}
+
+  def __init__(self):
+    self.parser = InsetParser()
+    self.output = TaggedOutput()
+
+  def process(self):
+    "Set the correct tag"
+    self.type = self.header[2]
+    if not self.type in BoxInset.typetags:
+      Trace.error('Uknown box type ' + self.type)
+      return
+    self.output.settag(BoxInset.typetags[self.type], True)
+
+
